==> mullvad-browser-debug-symbols-linux-x86_64-14.5.8.tar.xz: mullvad-browser/include/mozilla/dom/GeneratedEventList.h <==
GENERATED_EVENT(AddonEvent)
GENERATED_EVENT(AnimationPlaybackEvent)
GENERATED_EVENT(BlobEvent)
GENERATED_EVENT(CSSCustomPropertyRegisteredEvent)
GENERATED_EVENT(CaretStateChangedEvent)
GENERATED_EVENT(CloseEvent)
GENERATED_EVENT(ContentVisibilityAutoStateChangeEvent)
GENERATED_EVENT(DeviceLightEvent)
GENERATED_EVENT(DeviceOrientationEvent)
GENERATED_EVENT(ErrorEvent)
GENERATED_EVENT(FontFaceSetLoadEvent)
GENERATED_EVENT(FormDataEvent)
GENERATED_EVENT(FrameCrashedEvent)
GENERATED_EVENT(GPUUncapturedErrorEvent)
GENERATED_EVENT(GamepadAxisMoveEvent)
GENERATED_EVENT(GamepadButtonEvent)
GENERATED_EVENT(GamepadEvent)
GENERATED_EVENT(HashChangeEvent)
GENERATED_EVENT(ImageCaptureErrorEvent)
GENERATED_EVENT(MIDIConnectionEvent)
GENERATED_EVENT(MediaQueryListEvent)
GENERATED_EVENT(MediaRecorderErrorEvent)
GENERATED_EVENT(MediaStreamEvent)
GENERATED_EVENT(MediaStreamTrackEvent)
GENERATED_EVENT(OfflineAudioCompletionEvent)
GENERATED_EVENT(PageTransitionEvent)
GENERATED_EVENT(PerformanceEntryEvent)
GENERATED_EVENT(PluginCrashedEvent)
GENERATED_EVENT(PopStateEvent)
GENERATED_EVENT(PopupBlockedEvent)
GENERATED_EVENT(PopupPositionedEvent)
GENERATED_EVENT(PositionStateEvent)
GENERATED_EVENT(ProgressEvent)
GENERATED_EVENT(PromiseRejectionEvent)
GENERATED_EVENT(RTCDTMFToneChangeEvent)
GENERATED_EVENT(RTCDataChannelEvent)
GENERATED_EVENT(RTCPeerConnectionIceEvent)
GENERATED_EVENT(RTCTrackEvent)
GENERATED_EVENT(RTCTransformEvent)
GENERATED_EVENT(ScrollViewChangeEvent)
GENERATED_EVENT(SecurityPolicyViolationEvent)
GENERATED_EVENT(SpeechRecognitionEvent)
GENERATED_EVENT(SpeechSynthesisErrorEvent)
GENERATED_EVENT(SpeechSynthesisEvent)
GENERATED_EVENT(StyleSheetApplicableStateChangeEvent)
GENERATED_EVENT(StyleSheetRemovedEvent)
GENERATED_EVENT(SubmitEvent)
GENERATED_EVENT(TCPServerSocketEvent)
GENERATED_EVENT(TCPSocketErrorEvent)
GENERATED_EVENT(TCPSocketEvent)
GENERATED_EVENT(TaskPriorityChangeEvent)
GENERATED_EVENT(ToggleEvent)
GENERATED_EVENT(TrackEvent)
GENERATED_EVENT(UDPMessageEvent)
GENERATED_EVENT(UserProximityEvent)
GENERATED_EVENT(WebGLContextEvent)
GENERATED_EVENT(XRInputSourceEvent)
GENERATED_EVENT(XRInputSourcesChangeEvent)
GENERATED_EVENT(XRReferenceSpaceEvent)
GENERATED_EVENT(XRSessionEvent)

==> mullvad-browser-debug-symbols-linux-x86_64-15.0a4.tar.xz: mullvad-browser/include/mozilla/dom/GeneratedEventList.h <==
GENERATED_EVENT(AddonEvent)
GENERATED_EVENT(AnimationPlaybackEvent)
GENERATED_EVENT(BlobEvent)
GENERATED_EVENT(CSSCustomPropertyRegisteredEvent)
GENERATED_EVENT(CaretStateChangedEvent)
GENERATED_EVENT(CloseEvent)
GENERATED_EVENT(ContentVisibilityAutoStateChangeEvent)
GENERATED_EVENT(DeviceLightEvent)
GENERATED_EVENT(DeviceOrientationEvent)
GENERATED_EVENT(ErrorEvent)
GENERATED_EVENT(FontFaceSetLoadEvent)
GENERATED_EVENT(FormDataEvent)
GENERATED_EVENT(FrameCrashedEvent)
GENERATED_EVENT(GPUUncapturedErrorEvent)
GENERATED_EVENT(GamepadAxisMoveEvent)
GENERATED_EVENT(GamepadButtonEvent)
GENERATED_EVENT(GamepadEvent)
GENERATED_EVENT(HashChangeEvent)
GENERATED_EVENT(ImageCaptureErrorEvent)
GENERATED_EVENT(MIDIConnectionEvent)
GENERATED_EVENT(MediaQueryListEvent)
GENERATED_EVENT(MediaRecorderErrorEvent)
GENERATED_EVENT(MediaStreamEvent)
GENERATED_EVENT(MediaStreamTrackEvent)
GENERATED_EVENT(NavigationCurrentEntryChangeEvent)
GENERATED_EVENT(NotificationEvent)
GENERATED_EVENT(OfflineAudioCompletionEvent)
GENERATED_EVENT(PageTransitionEvent)
GENERATED_EVENT(PerformanceEntryEvent)
GENERATED_EVENT(PluginCrashedEvent)
GENERATED_EVENT(PopStateEvent)
GENERATED_EVENT(PopupBlockedEvent)
GENERATED_EVENT(PopupPositionedEvent)
GENERATED_EVENT(PositionStateEvent)
GENERATED_EVENT(ProgressEvent)
GENERATED_EVENT(PromiseRejectionEvent)
GENERATED_EVENT(PushSubscriptionChangeEvent)
GENERATED_EVENT(RTCDTMFToneChangeEvent)
GENERATED_EVENT(RTCDataChannelEvent)
GENERATED_EVENT(RTCPeerConnectionIceEvent)
GENERATED_EVENT(RTCTrackEvent)
GENERATED_EVENT(RTCTransformEvent)
GENERATED_EVENT(SecurityPolicyViolationEvent)
GENERATED_EVENT(SpeechRecognitionEvent)
GENERATED_EVENT(SpeechSynthesisErrorEvent)
GENERATED_EVENT(SpeechSynthesisEvent)
GENERATED_EVENT(StyleSheetApplicableStateChangeEvent)
GENERATED_EVENT(StyleSheetRemovedEvent)
GENERATED_EVENT(SubmitEvent)
GENERATED_EVENT(TCPServerSocketEvent)
GENERATED_EVENT(TCPSocketErrorEvent)
GENERATED_EVENT(TCPSocketEvent)
GENERATED_EVENT(TaskPriorityChangeEvent)
GENERATED_EVENT(ToggleEvent)
GENERATED_EVENT(TrackEvent)
GENERATED_EVENT(UDPMessageEvent)
GENERATED_EVENT(UserProximityEvent)
GENERATED_EVENT(WebGLContextEvent)
GENERATED_EVENT(XRInputSourceEvent)
GENERATED_EVENT(XRInputSourcesChangeEvent)
GENERATED_EVENT(XRReferenceSpaceEvent)
GENERATED_EVENT(XRSessionEvent)
